@@ -628,6 +628,66 @@ class APITestCase(TestCase):
         self.assertEqual(ops['get']['type'], 'Person')
         self.assertEqual(ops['post']['type'], 'Person')
 
+    def test_model_as_nested_dict(self):
+        address_fields = self.api.model('Address', {
+            'road': restplus.fields.String,
+        })
+
+        fields = self.api.model('Person', {
+            'name': restplus.fields.String,
+            'age': restplus.fields.Integer,
+            'birthdate': restplus.fields.DateTime,
+            'address': restplus.fields.Nested(address_fields)
+        })
+
+        @self.api.route('/model-as-dict/')
+        class ModelAsDict(restplus.Resource):
+            @self.api.doc(model=fields)
+            def get(self):
+                return {}
+
+            @self.api.doc(model='Person')
+            def post(self):
+                return {}
+
+        data = self.get_declaration()
+
+        self.assertIn('models', data)
+        self.assertIn('Person', data['models'].keys())
+        self.assertEqual(data['models']['Person'], {
+            'id': 'Person',
+            'properties': {
+                'name': {
+                    'type': 'string'
+                },
+                'age': {
+                    'type': 'integer'
+                },
+                'birthdate': {
+                    'type': 'string',
+                    'format': 'date-time'
+                },
+                'address': {
+                    '$ref': 'Address',
+                    'required': True,
+                }
+            }
+        })
+
+        self.assertIn('Address', data['models'].keys())
+        self.assertEqual(data['models']['Address'], {
+            'id': 'Address',
+            'properties': {
+                'road': {
+                    'type': 'string'
+                },
+            }
+        })
+
+        ops = dict((o['method'].lower(), o) for o in data['apis'][0]['operations'])
+        self.assertEqual(ops['get']['type'], 'Person')
+        self.assertEqual(ops['post']['type'], 'Person')
+
     def test_model_as_flat_dict_with_marchal_decorator(self):
         fields = self.api.model('Person', {
             'name': restplus.fields.String,
@@ -829,6 +889,58 @@ class APITestCase(TestCase):
 
         self.assertEqual(data['status'], 500)
 
+    def test_model_as_class(self):
+        @self.api.model('MyClass', fields={
+            'name': restplus.fields.String,
+        })
+        class MyModelField(restplus.fields.Raw):
+            pass
+
+        fields = self.api.model('Fake', {
+            'name': restplus.fields.String,
+            'nested': restplus.fields.Nested(MyModelField),
+        })
+
+        @self.api.route('/model-as-class/')
+        class ModelAsDict(restplus.Resource):
+            @self.api.doc(model=fields)
+            def get(self):
+                return {}
+
+            @self.api.doc(model='Fake')
+            def post(self):
+                return {}
+
+        data = self.get_declaration()
+
+        self.assertIn('models', data)
+        self.assertIn('Fake', data['models'].keys())
+        self.assertIn('MyClass', data['models'].keys())
+        self.assertEqual(data['models']['Fake'], {
+            'id': 'Fake',
+            'properties': {
+                'name': {
+                    'type': 'string'
+                },
+                'nested': {
+                    '$ref': 'MyClass',
+                    'required': True,
+                }
+            }
+        })
+        self.assertEqual(data['models']['MyClass'], {
+            'id': 'MyClass',
+            'properties': {
+                'name': {
+                    'type': 'string'
+                }
+            }
+        })
+
+        ops = dict((o['method'].lower(), o) for o in data['apis'][0]['operations'])
+        self.assertEqual(ops['get']['type'], 'Fake')
+        self.assertEqual(ops['post']['type'], 'Fake')
+
     def test_authorizations(self):
         authorizations = {
             'apikey': {
